# -*- coding: utf-8 -*-

"""
   Pinch.Configuration

   This file was automatically generated for Pinch by APIMATIC v2.0 ( https://apimatic.io ) on 05/13/2016
"""

class Configuration(object):
    # The base Uri for API calls
    BASE_URI = "https://api-company.inchbase.com/api/v1"

    # Your api key
    # TODO: Replace the x_api_token with an appropriate value
    x_api_token = "TODO: Replace"

    # Your registered email
    # TODO: Replace the x_api_email with an appropriate value
    x_api_email = "TODO: Replace"


